# CHANGELOG

<!-- version list -->

## v1.0.0 (2025-11-23)

### Features

- Add daily performance monitoring with github-action-benchmark
  ([`8140cff`](https://github.com/terrylica/rangebar-py/commit/8140cff02b6e00e8fd3e37175209bd36071389ee))

- **perf-monitoring**: Switch to GitHub Actions deployment source
  ([`c14403f`](https://github.com/terrylica/rangebar-py/commit/c14403f25058c435db9260ecfa364da232bdf9ed))


## v0.3.0 (2025-11-17)

### Features

- Release v0.3.0 with complete CI/CD infrastructure
  ([`5f6a19f`](https://github.com/terrylica/rangebar-py/commit/5f6a19f6b80c48afc278020c6689451b06250148))


## v0.2.0 (2025-11-17)

### Features

- Complete release automation infrastructure
  ([`4886cca`](https://github.com/terrylica/rangebar-py/commit/4886cca5e2a8020d066534a130cac4b40874b3b6))

## v0.1.1 (2025-11-17)

### Bug Fixes

- **ci**: Add pypi environment to publish job
  ([`4236b69`](https://github.com/terrylica/rangebar-py/commit/4236b69386e7be8732b3dd76a74ae6cc31b76f53))

## v0.1.0 (2025-11-17)

- Initial Release
